##  Overview
As an admin, you can create custom KPIs that meet your needs in the KPIs section of the administration area. You can also edit both custom and predefined KPIs. Users can add available KPIs to their dashboards.
